@@ -1,4 +1,4 @@
-#   Copyright 2020 The PyMC Developers
+#   Copyright 2023 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -12,11 +12,6 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-from pymc.distributions.logprob import (  # isort:skip
-    logcdf,
-    logp,
-)
-
 from pymc.distributions.bound import Bound
 from pymc.distributions.censored import Censored
 from pymc.distributions.continuous import (
@@ -199,6 +194,4 @@ __all__ = [
     "Censored",
     "CAR",
     "PolyaGamma",
-    "logp",
-    "logcdf",
 ]
