@@ -14,7 +14,7 @@
 import warnings
 
 import numpy as np
-import pytensor.tensor as at
+import pytensor.tensor as pt
 
 from pytensor.tensor import TensorConstant
 from pytensor.tensor.random.basic import (
@@ -48,7 +48,7 @@ from pymc.distributions.dist_math import (
 from pymc.distributions.distribution import Discrete
 from pymc.distributions.mixture import Mixture
 from pymc.distributions.shape_utils import rv_size_is_none
-from pymc.logprob.joint_logprob import logp
+from pymc.logprob.basic import logp
 from pymc.math import sigmoid
 from pymc.pytensorf import floatX, intX
 from pymc.vartypes import continuous_types
@@ -129,21 +129,21 @@ class Binomial(Discrete):
             raise ValueError("Incompatible parametrization. Must specify either p or logit_p.")
 
         if logit_p is not None:
-            p = at.sigmoid(logit_p)
+            p = pt.sigmoid(logit_p)
 
-        n = at.as_tensor_variable(intX(n))
-        p = at.as_tensor_variable(floatX(p))
+        n = pt.as_tensor_variable(intX(n))
+        p = pt.as_tensor_variable(floatX(p))
         return super().dist([n, p], **kwargs)
 
     def moment(rv, size, n, p):
-        mean = at.round(n * p)
+        mean = pt.round(n * p)
         if not rv_size_is_none(size):
-            mean = at.full(size, mean)
+            mean = pt.full(size, mean)
         return mean
 
     def logp(value, n, p):
-        res = at.switch(
-            at.or_(at.lt(value, 0), at.gt(value, n)),
+        res = pt.switch(
+            pt.or_(pt.lt(value, 0), pt.gt(value, n)),
             -np.inf,
             binomln(n, value) + logpow(p, value) + logpow(1 - p, n - value),
         )
@@ -157,14 +157,14 @@ class Binomial(Discrete):
         )
 
     def logcdf(value, n, p):
-        value = at.floor(value)
+        value = pt.floor(value)
 
-        res = at.switch(
-            at.lt(value, 0),
+        res = pt.switch(
+            pt.lt(value, 0),
             -np.inf,
-            at.switch(
-                at.lt(value, n),
-                at.log(at.betainc(n - value, value + 1, 1 - p)),
+            pt.switch(
+                pt.lt(value, n),
+                pt.log(pt.betainc(n - value, value + 1, 1 - p)),
                 0,
             ),
         )
@@ -239,20 +239,20 @@ class BetaBinomial(Discrete):
 
     @classmethod
     def dist(cls, alpha, beta, n, *args, **kwargs):
-        alpha = at.as_tensor_variable(floatX(alpha))
-        beta = at.as_tensor_variable(floatX(beta))
-        n = at.as_tensor_variable(intX(n))
+        alpha = pt.as_tensor_variable(floatX(alpha))
+        beta = pt.as_tensor_variable(floatX(beta))
+        n = pt.as_tensor_variable(intX(n))
         return super().dist([n, alpha, beta], **kwargs)
 
     def moment(rv, size, n, alpha, beta):
-        mean = at.round((n * alpha) / (alpha + beta))
+        mean = pt.round((n * alpha) / (alpha + beta))
         if not rv_size_is_none(size):
-            mean = at.full(size, mean)
+            mean = pt.full(size, mean)
         return mean
 
     def logp(value, n, alpha, beta):
-        res = at.switch(
-            at.or_(at.lt(value, 0), at.gt(value, n)),
+        res = pt.switch(
+            pt.or_(pt.lt(value, 0), pt.gt(value, n)),
             -np.inf,
             binomln(n, value) + betaln(value + alpha, n - value + beta) - betaln(alpha, beta),
         )
@@ -271,16 +271,16 @@ class BetaBinomial(Discrete):
                 f"BetaBinomial.logcdf expects a scalar value but received a {np.ndim(value)}-dimensional object."
             )
 
-        safe_lower = at.switch(at.lt(value, 0), value, 0)
-        res = at.switch(
-            at.lt(value, 0),
+        safe_lower = pt.switch(pt.lt(value, 0), value, 0)
+        res = pt.switch(
+            pt.lt(value, 0),
             -np.inf,
-            at.switch(
-                at.lt(value, n),
-                at.logsumexp(
+            pt.switch(
+                pt.lt(value, n),
+                pt.logsumexp(
                     logp(
                         BetaBinomial.dist(alpha=alpha, beta=beta, n=n),
-                        at.arange(safe_lower, value + 1),
+                        pt.arange(safe_lower, value + 1),
                     ),
                     keepdims=False,
                 ),
@@ -351,21 +351,21 @@ class Bernoulli(Discrete):
             raise ValueError("Incompatible parametrization. Must specify either p or logit_p.")
 
         if logit_p is not None:
-            p = at.sigmoid(logit_p)
+            p = pt.sigmoid(logit_p)
 
-        p = at.as_tensor_variable(floatX(p))
+        p = pt.as_tensor_variable(floatX(p))
         return super().dist([p], **kwargs)
 
     def moment(rv, size, p):
         if not rv_size_is_none(size):
-            p = at.full(size, p)
-        return at.switch(p < 0.5, 0, 1)
+            p = pt.full(size, p)
+        return pt.switch(p < 0.5, 0, 1)
 
     def logp(value, p):
-        res = at.switch(
-            at.or_(at.lt(value, 0), at.gt(value, 1)),
+        res = pt.switch(
+            pt.or_(pt.lt(value, 0), pt.gt(value, 1)),
             -np.inf,
-            at.switch(value, at.log(p), at.log1p(-p)),
+            pt.switch(value, pt.log(p), pt.log1p(-p)),
         )
 
         return check_parameters(
@@ -376,12 +376,12 @@ class Bernoulli(Discrete):
         )
 
     def logcdf(value, p):
-        res = at.switch(
-            at.lt(value, 0),
+        res = pt.switch(
+            pt.lt(value, 0),
             -np.inf,
-            at.switch(
-                at.lt(value, 1),
-                at.log1p(-p),
+            pt.switch(
+                pt.lt(value, 1),
+                pt.log1p(-p),
                 0,
             ),
         )
@@ -461,21 +461,21 @@ class DiscreteWeibull(Discrete):
 
     @classmethod
     def dist(cls, q, beta, *args, **kwargs):
-        q = at.as_tensor_variable(floatX(q))
-        beta = at.as_tensor_variable(floatX(beta))
+        q = pt.as_tensor_variable(floatX(q))
+        beta = pt.as_tensor_variable(floatX(beta))
         return super().dist([q, beta], **kwargs)
 
     def moment(rv, size, q, beta):
-        median = at.power(at.log(0.5) / at.log(q), 1 / beta) - 1
+        median = pt.power(pt.log(0.5) / pt.log(q), 1 / beta) - 1
         if not rv_size_is_none(size):
-            median = at.full(size, median)
+            median = pt.full(size, median)
         return median
 
     def logp(value, q, beta):
-        res = at.switch(
-            at.lt(value, 0),
+        res = pt.switch(
+            pt.lt(value, 0),
             -np.inf,
-            at.log(at.power(q, at.power(value, beta)) - at.power(q, at.power(value + 1, beta))),
+            pt.log(pt.power(q, pt.power(value, beta)) - pt.power(q, pt.power(value + 1, beta))),
         )
 
         return check_parameters(
@@ -487,10 +487,10 @@ class DiscreteWeibull(Discrete):
         )
 
     def logcdf(value, q, beta):
-        res = at.switch(
-            at.lt(value, 0),
+        res = pt.switch(
+            pt.lt(value, 0),
             -np.inf,
-            at.log1p(-at.power(q, at.power(value + 1, beta))),
+            pt.log1p(-pt.power(q, pt.power(value + 1, beta))),
         )
         return check_parameters(
             res,
@@ -550,24 +550,24 @@ class Poisson(Discrete):
 
     @classmethod
     def dist(cls, mu, *args, **kwargs):
-        mu = at.as_tensor_variable(floatX(mu))
+        mu = pt.as_tensor_variable(floatX(mu))
         return super().dist([mu], *args, **kwargs)
 
     def moment(rv, size, mu):
-        mu = at.floor(mu)
+        mu = pt.floor(mu)
         if not rv_size_is_none(size):
-            mu = at.full(size, mu)
+            mu = pt.full(size, mu)
         return mu
 
     def logp(value, mu):
-        res = at.switch(
-            at.lt(value, 0),
+        res = pt.switch(
+            pt.lt(value, 0),
             -np.inf,
             logpow(mu, value) - factln(value) - mu,
         )
         # Return zero when mu and value are both zero
-        res = at.switch(
-            at.eq(mu, 0) * at.eq(value, 0),
+        res = pt.switch(
+            pt.eq(mu, 0) * pt.eq(value, 0),
             0,
             res,
         )
@@ -578,15 +578,15 @@ class Poisson(Discrete):
         )
 
     def logcdf(value, mu):
-        value = at.floor(value)
+        value = pt.floor(value)
         # Avoid C-assertion when the gammaincc function is called with invalid values (#4340)
-        safe_mu = at.switch(at.lt(mu, 0), 0, mu)
-        safe_value = at.switch(at.lt(value, 0), 0, value)
+        safe_mu = pt.switch(pt.lt(mu, 0), 0, mu)
+        safe_value = pt.switch(pt.lt(value, 0), 0, value)
 
-        res = at.switch(
-            at.lt(value, 0),
+        res = pt.switch(
+            pt.lt(value, 0),
             -np.inf,
-            at.log(at.gammaincc(safe_value + 1, safe_mu)),
+            pt.log(pt.gammaincc(safe_value + 1, safe_mu)),
         )
 
         return check_parameters(
@@ -673,8 +673,8 @@ class NegativeBinomial(Discrete):
     @classmethod
     def dist(cls, mu=None, alpha=None, p=None, n=None, *args, **kwargs):
         n, p = cls.get_n_p(mu=mu, alpha=alpha, p=p, n=n)
-        n = at.as_tensor_variable(floatX(n))
-        p = at.as_tensor_variable(floatX(p))
+        n = pt.as_tensor_variable(floatX(n))
+        p = pt.as_tensor_variable(floatX(p))
         return super().dist([n, p], *args, **kwargs)
 
     @classmethod
@@ -698,17 +698,17 @@ class NegativeBinomial(Discrete):
         return n, p
 
     def moment(rv, size, n, p):
-        mu = at.floor(n * (1 - p) / p)
+        mu = pt.floor(n * (1 - p) / p)
         if not rv_size_is_none(size):
-            mu = at.full(size, mu)
+            mu = pt.full(size, mu)
         return mu
 
     def logp(value, n, p):
         alpha = n
         mu = alpha * (1 - p) / p
 
-        res = at.switch(
-            at.lt(value, 0),
+        res = pt.switch(
+            pt.lt(value, 0),
             -np.inf,
             (
                 binomln(value + alpha - 1, value)
@@ -725,13 +725,13 @@ class NegativeBinomial(Discrete):
         )
 
         # Return Poisson when alpha gets very large.
-        return at.switch(at.gt(alpha, 1e10), logp(Poisson.dist(mu=mu), value), negbinom)
+        return pt.switch(pt.gt(alpha, 1e10), logp(Poisson.dist(mu=mu), value), negbinom)
 
     def logcdf(value, n, p):
-        res = at.switch(
-            at.lt(value, 0),
+        res = pt.switch(
+            pt.lt(value, 0),
             -np.inf,
-            at.log(at.betainc(n, at.floor(value) + 1, p)),
+            pt.log(pt.betainc(n, pt.floor(value) + 1, p)),
         )
         return check_parameters(
             res,
@@ -785,20 +785,20 @@ class Geometric(Discrete):
 
     @classmethod
     def dist(cls, p, *args, **kwargs):
-        p = at.as_tensor_variable(floatX(p))
+        p = pt.as_tensor_variable(floatX(p))
         return super().dist([p], *args, **kwargs)
 
     def moment(rv, size, p):
-        mean = at.round(1.0 / p)
+        mean = pt.round(1.0 / p)
         if not rv_size_is_none(size):
-            mean = at.full(size, mean)
+            mean = pt.full(size, mean)
         return mean
 
     def logp(value, p):
-        res = at.switch(
-            at.lt(value, 1),
+        res = pt.switch(
+            pt.lt(value, 1),
             -np.inf,
-            at.log(p) + logpow(1 - p, value - 1),
+            pt.log(p) + logpow(1 - p, value - 1),
         )
 
         return check_parameters(
@@ -809,10 +809,10 @@ class Geometric(Discrete):
         )
 
     def logcdf(value, p):
-        res = at.switch(
-            at.lt(value, 0),
+        res = pt.switch(
+            pt.lt(value, 0),
             -np.inf,
-            at.log1mexp(at.log1p(-p) * value),
+            pt.log1mexp(pt.log1p(-p) * value),
         )
         return check_parameters(
             res,
@@ -822,7 +822,7 @@ class Geometric(Discrete):
         )
 
     def icdf(value, p):
-        res = at.ceil(at.log1p(-value) / at.log1p(-p)).astype("int64")
+        res = pt.ceil(pt.log1p(-value) / pt.log1p(-p)).astype("int64")
         res = check_icdf_value(res, value)
         return check_icdf_parameters(
             res,
@@ -882,16 +882,16 @@ class HyperGeometric(Discrete):
 
     @classmethod
     def dist(cls, N, k, n, *args, **kwargs):
-        good = at.as_tensor_variable(intX(k))
-        bad = at.as_tensor_variable(intX(N - k))
-        n = at.as_tensor_variable(intX(n))
+        good = pt.as_tensor_variable(intX(k))
+        bad = pt.as_tensor_variable(intX(N - k))
+        n = pt.as_tensor_variable(intX(n))
         return super().dist([good, bad, n], *args, **kwargs)
 
     def moment(rv, size, good, bad, n):
         N, k = good + bad, good
-        mode = at.floor((n + 1) * (k + 1) / (N + 2))
+        mode = pt.floor((n + 1) * (k + 1) / (N + 2))
         if not rv_size_is_none(size):
-            mode = at.full(size, mode)
+            mode = pt.full(size, mode)
         return mode
 
     def logp(value, good, bad, n):
@@ -905,14 +905,14 @@ class HyperGeometric(Discrete):
             - betaln(tot + 1, 1)
         )
         # value in [max(0, n - N + k), min(k, n)]
-        lower = at.switch(at.gt(n - tot + good, 0), n - tot + good, 0)
-        upper = at.switch(at.lt(good, n), good, n)
+        lower = pt.switch(pt.gt(n - tot + good, 0), n - tot + good, 0)
+        upper = pt.switch(pt.lt(good, n), good, n)
 
-        res = at.switch(
-            at.lt(value, lower),
+        res = pt.switch(
+            pt.lt(value, lower),
             -np.inf,
-            at.switch(
-                at.le(value, upper),
+            pt.switch(
+                pt.le(value, upper),
                 result,
                 -np.inf,
             ),
@@ -933,15 +933,15 @@ class HyperGeometric(Discrete):
 
         N = good + bad
         # TODO: Use lower upper in locgdf for smarter logsumexp?
-        safe_lower = at.switch(at.lt(value, 0), value, 0)
+        safe_lower = pt.switch(pt.lt(value, 0), value, 0)
 
-        res = at.switch(
-            at.lt(value, 0),
+        res = pt.switch(
+            pt.lt(value, 0),
             -np.inf,
-            at.switch(
-                at.lt(value, n),
-                at.logsumexp(
-                    HyperGeometric.logp(at.arange(safe_lower, value + 1), good, bad, n),
+            pt.switch(
+                pt.lt(value, n),
+                pt.logsumexp(
+                    HyperGeometric.logp(pt.arange(safe_lower, value + 1), good, bad, n),
                     keepdims=False,
                 ),
                 0,
@@ -1019,21 +1019,21 @@ class DiscreteUniform(Discrete):
 
     @classmethod
     def dist(cls, lower, upper, *args, **kwargs):
-        lower = intX(at.floor(lower))
-        upper = intX(at.floor(upper))
+        lower = intX(pt.floor(lower))
+        upper = intX(pt.floor(upper))
         return super().dist([lower, upper], **kwargs)
 
     def moment(rv, size, lower, upper):
-        mode = at.maximum(at.floor((upper + lower) / 2.0), lower)
+        mode = pt.maximum(pt.floor((upper + lower) / 2.0), lower)
         if not rv_size_is_none(size):
-            mode = at.full(size, mode)
+            mode = pt.full(size, mode)
         return mode
 
     def logp(value, lower, upper):
-        res = at.switch(
-            at.or_(at.lt(value, lower), at.gt(value, upper)),
+        res = pt.switch(
+            pt.or_(pt.lt(value, lower), pt.gt(value, upper)),
             -np.inf,
-            at.fill(value, -at.log(upper - lower + 1)),
+            pt.fill(value, -pt.log(upper - lower + 1)),
         )
         return check_parameters(
             res,
@@ -1042,12 +1042,12 @@ class DiscreteUniform(Discrete):
         )
 
     def logcdf(value, lower, upper):
-        res = at.switch(
-            at.le(value, lower),
+        res = pt.switch(
+            pt.le(value, lower),
             -np.inf,
-            at.switch(
-                at.lt(value, upper),
-                at.log(at.minimum(at.floor(value), upper) - lower + 1) - at.log(upper - lower + 1),
+            pt.switch(
+                pt.lt(value, upper),
+                pt.log(pt.minimum(pt.floor(value), upper) - lower + 1) - pt.log(upper - lower + 1),
                 0,
             ),
         )
@@ -1058,6 +1058,15 @@ class DiscreteUniform(Discrete):
             msg="lower <= upper",
         )
 
+    def icdf(value, lower, upper):
+        res = pt.ceil(value * (upper - lower + 1)).astype("int64") + lower - 1
+        res = check_icdf_value(res, value)
+        return check_icdf_parameters(
+            res,
+            lower <= upper,
+            msg="lower <= upper",
+        )
+
 
 class Categorical(Discrete):
     R"""
@@ -1108,7 +1117,7 @@ class Categorical(Discrete):
         if logit_p is not None:
             p = pm.math.softmax(logit_p, axis=-1)
 
-        p = at.as_tensor_variable(p)
+        p = pt.as_tensor_variable(p)
         if isinstance(p, TensorConstant):
             p_ = np.asarray(p.data)
             if np.any(p_ < 0):
@@ -1121,38 +1130,38 @@ class Categorical(Discrete):
                     "You can rescale them directly to get rid of this warning.",
                     UserWarning,
                 )
-                p_ = p_ / at.sum(p_, axis=-1, keepdims=True)
-                p = at.as_tensor_variable(p_)
+                p_ = p_ / pt.sum(p_, axis=-1, keepdims=True)
+                p = pt.as_tensor_variable(p_)
         return super().dist([p], **kwargs)
 
     def moment(rv, size, p):
-        mode = at.argmax(p, axis=-1)
+        mode = pt.argmax(p, axis=-1)
         if not rv_size_is_none(size):
-            mode = at.full(size, mode)
+            mode = pt.full(size, mode)
         return mode
 
     def logp(value, p):
-        k = at.shape(p)[-1]
+        k = pt.shape(p)[-1]
         p_ = p
-        value_clip = at.clip(value, 0, k - 1)
+        value_clip = pt.clip(value, 0, k - 1)
 
         if p.ndim > 1:
             if p.ndim > value_clip.ndim:
-                value_clip = at.shape_padleft(value_clip, p_.ndim - value_clip.ndim)
+                value_clip = pt.shape_padleft(value_clip, p_.ndim - value_clip.ndim)
             elif p.ndim < value_clip.ndim:
-                p = at.shape_padleft(p, value_clip.ndim - p_.ndim)
+                p = pt.shape_padleft(p, value_clip.ndim - p_.ndim)
             pattern = (p.ndim - 1,) + tuple(range(p.ndim - 1))
-            a = at.log(
-                at.take_along_axis(
+            a = pt.log(
+                pt.take_along_axis(
                     p.dimshuffle(pattern),
                     value_clip,
                 )
             )
         else:
-            a = at.log(p[value_clip])
+            a = pt.log(p[value_clip])
 
-        res = at.switch(
-            at.or_(at.lt(value, 0), at.gt(value, k - 1)),
+        res = pt.switch(
+            pt.or_(pt.lt(value, 0), pt.gt(value, k - 1)),
             -np.inf,
             a,
         )
@@ -1161,7 +1170,7 @@ class Categorical(Discrete):
             res,
             0 <= p_,
             p_ <= 1,
-            at.isclose(at.sum(p, axis=-1), 1),
+            pt.isclose(pt.sum(p, axis=-1), 1),
             msg="0 <= p <=1, sum(p) = 1",
         )
 
@@ -1173,7 +1182,7 @@ class DiracDeltaRV(RandomVariable):
     _print_name = ("DiracDelta", "\\operatorname{DiracDelta}")
 
     def make_node(self, rng, size, dtype, c):
-        c = at.as_tensor_variable(c)
+        c = pt.as_tensor_variable(c)
         return super().make_node(rng, size, c.dtype, c)
 
     @classmethod
@@ -1202,26 +1211,26 @@ class DiracDelta(Discrete):
 
     @classmethod
     def dist(cls, c, *args, **kwargs):
-        c = at.as_tensor_variable(c)
+        c = pt.as_tensor_variable(c)
         if c.dtype in continuous_types:
             c = floatX(c)
         return super().dist([c], **kwargs)
 
     def moment(rv, size, c):
         if not rv_size_is_none(size):
-            c = at.full(size, c)
+            c = pt.full(size, c)
         return c
 
     def logp(value, c):
-        return at.switch(
-            at.eq(value, c),
-            at.zeros_like(value),
+        return pt.switch(
+            pt.eq(value, c),
+            pt.zeros_like(value),
             -np.inf,
         )
 
     def logcdf(value, c):
-        return at.switch(
-            at.lt(value, c),
+        return pt.switch(
+            pt.lt(value, c),
             -np.inf,
             0,
         )
@@ -1249,8 +1258,8 @@ def _zero_inflated_mixture(*, name, nonzero_p, nonzero_dist, **kwargs):
 
     If name is `None`, this function returns an unregistered variable
     """
-    nonzero_p = at.as_tensor_variable(floatX(nonzero_p))
-    weights = at.stack([1 - nonzero_p, nonzero_p], axis=-1)
+    nonzero_p = pt.as_tensor_variable(floatX(nonzero_p))
+    weights = pt.stack([1 - nonzero_p, nonzero_p], axis=-1)
     comp_dists = [
         DiracDelta.dist(0),
         nonzero_dist,
@@ -1499,15 +1508,15 @@ class _OrderedLogistic(Categorical):
 
     @classmethod
     def dist(cls, eta, cutpoints, *args, **kwargs):
-        eta = at.as_tensor_variable(floatX(eta))
-        cutpoints = at.as_tensor_variable(cutpoints)
+        eta = pt.as_tensor_variable(floatX(eta))
+        cutpoints = pt.as_tensor_variable(cutpoints)
 
-        pa = sigmoid(cutpoints - at.shape_padright(eta))
-        p_cum = at.concatenate(
+        pa = sigmoid(cutpoints - pt.shape_padright(eta))
+        p_cum = pt.concatenate(
             [
-                at.zeros_like(at.shape_padright(pa[..., 0])),
+                pt.zeros_like(pt.shape_padright(pa[..., 0])),
                 pa,
-                at.ones_like(at.shape_padright(pa[..., 0])),
+                pt.ones_like(pt.shape_padright(pa[..., 0])),
             ],
             axis=-1,
         )
@@ -1572,7 +1581,7 @@ class OrderedLogistic:
         # Ordered logistic regression
         with pm.Model() as model:
             cutpoints = pm.Normal("cutpoints", mu=[-1,1], sigma=10, shape=2,
-                                  transform=pm.distributions.transforms.ordered)
+                                  transform=pm.distributions.transforms.univariate_ordered)
             y_ = pm.OrderedLogistic("y", cutpoints=cutpoints, eta=x, observed=y)
             idata = pm.sample()
 
@@ -1605,22 +1614,22 @@ class _OrderedProbit(Categorical):
 
     @classmethod
     def dist(cls, eta, cutpoints, sigma=1, *args, **kwargs):
-        eta = at.as_tensor_variable(floatX(eta))
-        cutpoints = at.as_tensor_variable(cutpoints)
+        eta = pt.as_tensor_variable(floatX(eta))
+        cutpoints = pt.as_tensor_variable(cutpoints)
 
-        probits = at.shape_padright(eta) - cutpoints
-        _log_p = at.concatenate(
+        probits = pt.shape_padright(eta) - cutpoints
+        _log_p = pt.concatenate(
             [
-                at.shape_padright(normal_lccdf(0, sigma, probits[..., 0])),
+                pt.shape_padright(normal_lccdf(0, sigma, probits[..., 0])),
                 log_diff_normal_cdf(
-                    0, at.shape_padright(sigma), probits[..., :-1], probits[..., 1:]
+                    0, pt.shape_padright(sigma), probits[..., :-1], probits[..., 1:]
                 ),
-                at.shape_padright(normal_lcdf(0, sigma, probits[..., -1])),
+                pt.shape_padright(normal_lcdf(0, sigma, probits[..., -1])),
             ],
             axis=-1,
         )
-        _log_p = at.as_tensor_variable(floatX(_log_p))
-        p = at.exp(_log_p)
+        _log_p = pt.as_tensor_variable(floatX(_log_p))
+        p = pt.exp(_log_p)
 
         return super().dist(p, *args, **kwargs)
 
