@@ -40,7 +40,7 @@ from copy import copy
 from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
 
 import numpy as np
-import pytensor.tensor as at
+import pytensor.tensor as pt
 
 from pytensor.gradient import DisconnectedType, jacobian
 from pytensor.graph.basic import Apply, Node, Variable
@@ -77,12 +77,15 @@ from pymc.logprob.abstract import (
     MeasurableElemwise,
     MeasurableVariable,
     _get_measurable_outputs,
+    _icdf,
+    _icdf_helper,
+    _logcdf,
+    _logcdf_helper,
     _logprob,
-    assign_custom_measurable_outputs,
-    logprob,
+    _logprob_helper,
 )
 from pymc.logprob.rewriting import PreserveRVMappings, measurable_ir_rewrites_db
-from pymc.logprob.utils import walk_model
+from pymc.logprob.utils import ignore_logprob, walk_model
 
 
 class TransformedVariable(Op):
@@ -132,12 +135,12 @@ class RVTransform(abc.ABC):
 
     def log_jac_det(self, value: TensorVariable, *inputs) -> TensorVariable:
         """Construct the log of the absolute value of the Jacobian determinant."""
-        # jac = at.reshape(
-        #     gradient(at.sum(self.backward(value, *inputs)), [value]), value.shape
+        # jac = pt.reshape(
+        #     gradient(pt.sum(self.backward(value, *inputs)), [value]), value.shape
         # )
-        # return at.log(at.abs(jac))
+        # return pt.log(pt.abs(jac))
         phi_inv = self.backward(value, *inputs)
-        return at.log(at.abs(at.nlinalg.det(at.atleast_2d(jacobian(phi_inv, [value])[0]))))
+        return pt.log(pt.abs(pt.nlinalg.det(pt.atleast_2d(jacobian(phi_inv, [value])[0]))))
 
 
 @node_rewriter(tracks=None)
@@ -369,20 +372,58 @@ def measurable_transform_logprob(op: MeasurableTransform, values, *inputs, **kwa
 
     # Some transformations, like squaring may produce multiple backward values
     if isinstance(backward_value, tuple):
-        input_logprob = at.logaddexp(
-            *(logprob(measurable_input, backward_val, **kwargs) for backward_val in backward_value)
+        input_logprob = pt.logaddexp(
+            *(
+                _logprob_helper(measurable_input, backward_val, **kwargs)
+                for backward_val in backward_value
+            )
         )
     else:
-        input_logprob = logprob(measurable_input, backward_value)
-
-    if input_logprob.ndim < value.ndim:
-        # Do we just need to sum the jacobian terms across the support dims?
-        raise NotImplementedError("Transform of multivariate RVs not implemented")
+        input_logprob = _logprob_helper(measurable_input, backward_value)
 
     jacobian = op.transform_elemwise.log_jac_det(value, *other_inputs)
 
+    if input_logprob.ndim < value.ndim:
+        # For multivariate variables, the Jacobian is diagonal.
+        # We can get the right result by summing the last dimensions
+        # of `transform_elemwise.log_jac_det`
+        ndim_supp = value.ndim - input_logprob.ndim
+        jacobian = jacobian.sum(axis=tuple(range(-ndim_supp, 0)))
+
     # The jacobian is used to ensure a value in the supported domain was provided
-    return at.switch(at.isnan(jacobian), -np.inf, input_logprob + jacobian)
+    return pt.switch(pt.isnan(jacobian), -np.inf, input_logprob + jacobian)
+
+
+@_logcdf.register(MeasurableTransform)
+def measurable_transform_logcdf(op: MeasurableTransform, value, *inputs, **kwargs):
+    """Compute the log-CDF graph for a `MeasurabeTransform`."""
+    other_inputs = list(inputs)
+    measurable_input = other_inputs.pop(op.measurable_input_idx)
+
+    backward_value = op.transform_elemwise.backward(value, *other_inputs)
+
+    # Some transformations, like squaring may produce multiple backward values
+    if isinstance(backward_value, tuple):
+        raise NotImplementedError
+
+    input_logcdf = _logcdf_helper(measurable_input, backward_value)
+
+    # The jacobian is used to ensure a value in the supported domain was provided
+    jacobian = op.transform_elemwise.log_jac_det(value, *other_inputs)
+
+    return pt.switch(pt.isnan(jacobian), -np.inf, input_logcdf)
+
+
+@_icdf.register(MeasurableTransform)
+def measurable_transform_icdf(op: MeasurableTransform, value, *inputs, **kwargs):
+    """Compute the inverse CDF graph for a `MeasurabeTransform`."""
+    other_inputs = list(inputs)
+    measurable_input = other_inputs.pop(op.measurable_input_idx)
+
+    input_icdf = _icdf_helper(measurable_input, value)
+    icdf = op.transform_elemwise.forward(input_icdf, *other_inputs)
+
+    return icdf
 
 
 @node_rewriter([reciprocal])
@@ -400,7 +441,7 @@ def measurable_reciprocal_to_power(fgraph, node):
     if inp in rv_map_feature.rv_values:
         return None  # pragma: no cover
 
-    return [at.pow(inp, -1.0)]
+    return [pt.pow(inp, -1.0)]
 
 
 @node_rewriter([sqr, sqrt])
@@ -420,10 +461,10 @@ def measurable_sqrt_sqr_to_power(fgraph, node):
         return None  # pragma: no cover
 
     if isinstance(node.op.scalar_op, Sqr):
-        return [at.pow(inp, 2)]
+        return [pt.pow(inp, 2)]
 
     if isinstance(node.op.scalar_op, Sqrt):
-        return [at.pow(inp, 1 / 2)]
+        return [pt.pow(inp, 1 / 2)]
 
 
 @node_rewriter([true_div])
@@ -448,15 +489,15 @@ def measurable_div_to_product(fgraph, node):
 
     # Check if numerator is 1
     try:
-        if at.get_scalar_constant_value(numerator) == 1:
+        if pt.get_scalar_constant_value(numerator) == 1:
             # We convert the denominator directly to a power transform as this
             # must be the measurable input
-            return [at.pow(denominator, -1)]
+            return [pt.pow(denominator, -1)]
     except NotScalarConstantError:
         pass
     # We don't convert the denominator directly to a power transform as
     # it might not be measurable (and therefore not needed)
-    return [at.mul(numerator, at.reciprocal(denominator))]
+    return [pt.mul(numerator, pt.reciprocal(denominator))]
 
 
 @node_rewriter([neg])
@@ -475,7 +516,7 @@ def measurable_neg_to_product(fgraph, node):
     if inp in rv_map_feature.rv_values:
         return None  # pragma: no cover
 
-    return [at.mul(inp, -1.0)]
+    return [pt.mul(inp, -1.0)]
 
 
 @node_rewriter([sub])
@@ -496,7 +537,7 @@ def measurable_sub_to_neg(fgraph, node):
         return None  # pragma: no cover
 
     minuend, subtrahend = node.inputs
-    return [at.add(minuend, at.neg(subtrahend))]
+    return [pt.add(minuend, pt.neg(subtrahend))]
 
 
 @node_rewriter([exp, log, add, mul, pow, abs])
@@ -549,7 +590,7 @@ def find_measurable_transforms(fgraph: FunctionGraph, node: Node) -> Optional[Li
 
     # Make base_measure outputs unmeasurable
     # This seems to be the only thing preventing nested rewrites from being erased
-    measurable_input = assign_custom_measurable_outputs(measurable_input.owner)
+    measurable_input = ignore_logprob(measurable_input)
 
     scalar_op = node.op.scalar_op
     measurable_input_idx = 0
@@ -567,19 +608,19 @@ def find_measurable_transforms(fgraph: FunctionGraph, node: Node) -> Optional[Li
             return None
         try:
             (power,) = other_inputs
-            power = at.get_scalar_constant_value(power).item()
+            power = pt.get_scalar_constant_value(power).item()
         # Power needs to be a constant
         except NotScalarConstantError:
             return None
         transform_inputs = (measurable_input, power)
         transform = PowerTransform(power=power)
     elif isinstance(scalar_op, Add):
-        transform_inputs = (measurable_input, at.add(*other_inputs))
+        transform_inputs = (measurable_input, pt.add(*other_inputs))
         transform = LocTransform(
             transform_args_fn=lambda *inputs: inputs[-1],
         )
     else:
-        transform_inputs = (measurable_input, at.mul(*other_inputs))
+        transform_inputs = (measurable_input, pt.mul(*other_inputs))
         transform = ScaleTransform(
             transform_args_fn=lambda *inputs: inputs[-1],
         )
@@ -656,7 +697,7 @@ class LocTransform(RVTransform):
         return value - loc
 
     def log_jac_det(self, value, *inputs):
-        return at.zeros_like(value)
+        return pt.zeros_like(value)
 
 
 class ScaleTransform(RVTransform):
@@ -675,17 +716,17 @@ class ScaleTransform(RVTransform):
 
     def log_jac_det(self, value, *inputs):
         scale = self.transform_args_fn(*inputs)
-        return -at.log(at.abs(scale))
+        return -pt.log(pt.abs(pt.broadcast_to(scale, value.shape)))
 
 
 class LogTransform(RVTransform):
     name = "log"
 
     def forward(self, value, *inputs):
-        return at.log(value)
+        return pt.log(value)
 
     def backward(self, value, *inputs):
-        return at.exp(value)
+        return pt.exp(value)
 
     def log_jac_det(self, value, *inputs):
         return value
@@ -695,27 +736,27 @@ class ExpTransform(RVTransform):
     name = "exp"
 
     def forward(self, value, *inputs):
-        return at.exp(value)
+        return pt.exp(value)
 
     def backward(self, value, *inputs):
-        return at.log(value)
+        return pt.log(value)
 
     def log_jac_det(self, value, *inputs):
-        return -at.log(value)
+        return -pt.log(value)
 
 
 class AbsTransform(RVTransform):
     name = "abs"
 
     def forward(self, value, *inputs):
-        return at.abs(value)
+        return pt.abs(value)
 
     def backward(self, value, *inputs):
-        value = at.switch(value >= 0, value, np.nan)
+        value = pt.switch(value >= 0, value, np.nan)
         return -value, value
 
     def log_jac_det(self, value, *inputs):
-        return at.switch(value >= 0, 0, np.nan)
+        return pt.switch(value >= 0, 0, np.nan)
 
 
 class PowerTransform(RVTransform):
@@ -730,17 +771,17 @@ class PowerTransform(RVTransform):
         super().__init__()
 
     def forward(self, value, *inputs):
-        at.power(value, self.power)
+        pt.power(value, self.power)
 
     def backward(self, value, *inputs):
         inv_power = 1 / self.power
 
         # Powers that don't admit negative values
         if (np.abs(self.power) < 1) or (self.power % 2 == 0):
-            backward_value = at.switch(value >= 0, at.power(value, inv_power), np.nan)
+            backward_value = pt.switch(value >= 0, pt.power(value, inv_power), np.nan)
         # Powers that admit negative values require special logic, because (-1)**(1/3) returns `nan` in PyTensor
         else:
-            backward_value = at.power(at.abs(value), inv_power) * at.switch(value >= 0, 1, -1)
+            backward_value = pt.power(pt.abs(value), inv_power) * pt.switch(value >= 0, 1, -1)
 
         # In this case the transform is not 1-to-1
         if self.power % 2 == 0:
@@ -752,11 +793,11 @@ class PowerTransform(RVTransform):
         inv_power = 1 / self.power
 
         # Note: This fails for value==0
-        res = np.log(np.abs(inv_power)) + (inv_power - 1) * at.log(at.abs(value))
+        res = np.log(np.abs(inv_power)) + (inv_power - 1) * pt.log(pt.abs(value))
 
         # Powers that don't admit negative values
         if (np.abs(self.power) < 1) or (self.power % 2 == 0):
-            res = at.switch(value >= 0, res, np.nan)
+            res = pt.switch(value >= 0, res, np.nan)
 
         return res
 
@@ -780,11 +821,11 @@ class IntervalTransform(RVTransform):
         a, b = self.args_fn(*inputs)
 
         if a is not None and b is not None:
-            return at.log(value - a) - at.log(b - value)
+            return pt.log(value - a) - pt.log(b - value)
         elif a is not None:
-            return at.log(value - a)
+            return pt.log(value - a)
         elif b is not None:
-            return at.log(b - value)
+            return pt.log(b - value)
         else:
             raise ValueError("Both edges of IntervalTransform cannot be None")
 
@@ -792,12 +833,12 @@ class IntervalTransform(RVTransform):
         a, b = self.args_fn(*inputs)
 
         if a is not None and b is not None:
-            sigmoid_x = at.sigmoid(value)
+            sigmoid_x = pt.sigmoid(value)
             return sigmoid_x * b + (1 - sigmoid_x) * a
         elif a is not None:
-            return at.exp(value) + a
+            return pt.exp(value) + a
         elif b is not None:
-            return b - at.exp(value)
+            return b - pt.exp(value)
         else:
             raise ValueError("Both edges of IntervalTransform cannot be None")
 
@@ -805,8 +846,8 @@ class IntervalTransform(RVTransform):
         a, b = self.args_fn(*inputs)
 
         if a is not None and b is not None:
-            s = at.softplus(-value)
-            return at.log(b - a) - 2 * s - value
+            s = pt.softplus(-value)
+            return pt.log(b - a) - 2 * s - value
         elif a is None and b is None:
             raise ValueError("Both edges of IntervalTransform cannot be None")
         else:
@@ -817,50 +858,50 @@ class LogOddsTransform(RVTransform):
     name = "logodds"
 
     def backward(self, value, *inputs):
-        return at.expit(value)
+        return pt.expit(value)
 
     def forward(self, value, *inputs):
-        return at.log(value / (1 - value))
+        return pt.log(value / (1 - value))
 
     def log_jac_det(self, value, *inputs):
-        sigmoid_value = at.sigmoid(value)
-        return at.log(sigmoid_value) + at.log1p(-sigmoid_value)
+        sigmoid_value = pt.sigmoid(value)
+        return pt.log(sigmoid_value) + pt.log1p(-sigmoid_value)
 
 
 class SimplexTransform(RVTransform):
     name = "simplex"
 
     def forward(self, value, *inputs):
-        log_value = at.log(value)
-        shift = at.sum(log_value, -1, keepdims=True) / value.shape[-1]
+        log_value = pt.log(value)
+        shift = pt.sum(log_value, -1, keepdims=True) / value.shape[-1]
         return log_value[..., :-1] - shift
 
     def backward(self, value, *inputs):
-        value = at.concatenate([value, -at.sum(value, -1, keepdims=True)], axis=-1)
-        exp_value_max = at.exp(value - at.max(value, -1, keepdims=True))
-        return exp_value_max / at.sum(exp_value_max, -1, keepdims=True)
+        value = pt.concatenate([value, -pt.sum(value, -1, keepdims=True)], axis=-1)
+        exp_value_max = pt.exp(value - pt.max(value, -1, keepdims=True))
+        return exp_value_max / pt.sum(exp_value_max, -1, keepdims=True)
 
     def log_jac_det(self, value, *inputs):
         N = value.shape[-1] + 1
-        sum_value = at.sum(value, -1, keepdims=True)
+        sum_value = pt.sum(value, -1, keepdims=True)
         value_sum_expanded = value + sum_value
-        value_sum_expanded = at.concatenate([value_sum_expanded, at.zeros(sum_value.shape)], -1)
-        logsumexp_value_expanded = at.logsumexp(value_sum_expanded, -1, keepdims=True)
-        res = at.log(N) + (N * sum_value) - (N * logsumexp_value_expanded)
-        return at.sum(res, -1)
+        value_sum_expanded = pt.concatenate([value_sum_expanded, pt.zeros(sum_value.shape)], -1)
+        logsumexp_value_expanded = pt.logsumexp(value_sum_expanded, -1, keepdims=True)
+        res = pt.log(N) + (N * sum_value) - (N * logsumexp_value_expanded)
+        return pt.sum(res, -1)
 
 
 class CircularTransform(RVTransform):
     name = "circular"
 
     def backward(self, value, *inputs):
-        return at.arctan2(at.sin(value), at.cos(value))
+        return pt.arctan2(pt.sin(value), pt.cos(value))
 
     def forward(self, value, *inputs):
-        return at.as_tensor_variable(value)
+        return pt.as_tensor_variable(value)
 
     def log_jac_det(self, value, *inputs):
-        return at.zeros(value.shape)
+        return pt.zeros(value.shape)
 
 
 class ChainedTransform(RVTransform):
@@ -881,7 +922,7 @@ class ChainedTransform(RVTransform):
         return value
 
     def log_jac_det(self, value, *inputs):
-        value = at.as_tensor_variable(value)
+        value = pt.as_tensor_variable(value)
         det_list = []
         ndim0 = value.ndim
         for transform in reversed(self.transform_list):
@@ -893,7 +934,8 @@ class ChainedTransform(RVTransform):
         det = 0.0
         for det_ in det_list:
             if det_.ndim > ndim0:
-                det += det_.sum(axis=-1)
+                ndim_diff = det_.ndim - ndim0
+                det += det_.sum(axis=tuple(range(-ndim_diff, 0)))
             else:
                 det += det_
         return det
