@@ -17,7 +17,7 @@ import functools as ft
 import numpy as np
 import numpy.testing as npt
 import pytensor
-import pytensor.tensor as at
+import pytensor.tensor as pt
 import pytest
 import scipy.special as sp
 import scipy.stats as st
@@ -26,10 +26,9 @@ from pytensor.compile.mode import Mode
 
 import pymc as pm
 
-from pymc.distributions.continuous import Normal, get_tau_sigma, interpolated
+from pymc.distributions.continuous import Normal, Uniform, get_tau_sigma, interpolated
 from pymc.distributions.dist_math import clipped_beta_rvs
-from pymc.logprob.abstract import logcdf
-from pymc.logprob.joint_logprob import logp
+from pymc.logprob.basic import icdf, logcdf, logp
 from pymc.logprob.utils import ParameterValueError
 from pymc.pytensorf import floatX
 from pymc.testing import (
@@ -176,6 +175,12 @@ class TestMatchesScipy:
             lambda value, lower, upper: st.uniform.logcdf(value, lower, upper - lower),
             skip_paramdomain_outside_edge_test=True,
         )
+        check_icdf(
+            pm.Uniform,
+            {"lower": -Rplusunif, "upper": Rplusunif},
+            lambda q, lower, upper: st.uniform.ppf(q=q, loc=lower, scale=upper - lower),
+            skip_paramdomain_outside_edge_test=True,
+        )
         # Custom logp / logcdf check for invalid parameters
         invalid_dist = pm.Uniform.dist(lower=1, upper=0)
         with pytensor.config.change_flags(mode=Mode("py")):
@@ -183,6 +188,8 @@ class TestMatchesScipy:
                 logp(invalid_dist, np.array(0.5)).eval()
             with pytest.raises(ParameterValueError):
                 logcdf(invalid_dist, np.array(0.5)).eval()
+            with pytest.raises(ParameterValueError):
+                icdf(invalid_dist, np.array(0.5)).eval()
 
     def test_triangular(self):
         check_logp(
@@ -354,9 +361,11 @@ class TestMatchesScipy:
         # http://www.gamlss.org/.
         with pm.Model() as model:
             pm.Wald("wald", mu=mu, lam=lam, phi=phi, alpha=alpha, transform=None)
-        pt = {"wald": value}
+        point = {"wald": value}
         decimals = select_by_precision(float64=6, float32=1)
-        npt.assert_almost_equal(model.compile_logp()(pt), logp, decimal=decimals, err_msg=str(pt))
+        npt.assert_almost_equal(
+            model.compile_logp()(point), logp, decimal=decimals, err_msg=str(point)
+        )
 
     def test_beta_logp(self):
         check_logp(
@@ -887,11 +896,11 @@ class TestMatchesScipy:
         tau = np.array(2)
         npt.assert_almost_equal(get_tau_sigma(tau=tau), [tau, tau**-0.5])
 
-        tau, _ = get_tau_sigma(sigma=at.constant(-2))
+        tau, _ = get_tau_sigma(sigma=pt.constant(-2))
         with pytest.raises(ParameterValueError):
             tau.eval()
 
-        _, sigma = get_tau_sigma(tau=at.constant(-2))
+        _, sigma = get_tau_sigma(tau=pt.constant(-2))
         with pytest.raises(ParameterValueError):
             sigma.eval()
 
@@ -921,12 +930,12 @@ class TestMatchesScipy:
         See e.g., doi: 10.1111/j.1467-9876.2005.00510.x, or http://www.gamlss.org/."""
         with pm.Model() as model:
             pm.ExGaussian("eg", mu=mu, sigma=sigma, nu=nu)
-        pt = {"eg": value}
+        point = {"eg": value}
         npt.assert_almost_equal(
-            model.compile_logp()(pt),
+            model.compile_logp()(point),
             logp,
             decimal=select_by_precision(float64=6, float32=2),
-            err_msg=str(pt),
+            err_msg=str(point),
         )
 
 
