@@ -36,7 +36,7 @@
 
 import numpy as np
 import pytensor
-import pytensor.tensor as at
+import pytensor.tensor as pt
 import pytest
 
 from pytensor import Mode
@@ -44,8 +44,8 @@ from pytensor.raise_op import assert_op
 from pytensor.scan.utils import ScanArgs
 from scipy import stats
 
-from pymc.logprob.abstract import logprob
-from pymc.logprob.joint_logprob import factorized_joint_logprob, logp
+from pymc.logprob.abstract import _logprob_helper
+from pymc.logprob.basic import factorized_joint_logprob, logp
 from pymc.logprob.scan import (
     construct_scan,
     convert_outer_out_to_in,
@@ -63,7 +63,7 @@ def create_inner_out_logp(value_map):
     """
     res = []
     for old_inner_out_var, new_inner_in_var in value_map.items():
-        logp = logprob(old_inner_out_var, new_inner_in_var)
+        logp = _logprob_helper(old_inner_out_var, new_inner_in_var)
         if new_inner_in_var.name:
             logp.name = f"logp({new_inner_in_var.name})"
         res.append(logp)
@@ -93,17 +93,17 @@ def test_convert_outer_out_to_in_sit_sot():
         y_tm1.name = "y_tm1"
         mu = mu_tm1 + y_tm1 + 1
         mu.name = "mu_t"
-        return mu, at.random.normal(mu, 1.0, rng=rng, name="Y_t")
+        return mu, pt.random.normal(mu, 1.0, rng=rng, name="Y_t")
 
     (mu_tt, Y_rv), _ = pytensor.scan(
         fn=input_step_fn,
         outputs_info=[
             {
-                "initial": at.as_tensor_variable(0.0, dtype=pytensor.config.floatX),
+                "initial": pt.as_tensor_variable(0.0, dtype=pytensor.config.floatX),
                 "taps": [-1],
             },
             {
-                "initial": at.as_tensor_variable(0.0, dtype=pytensor.config.floatX),
+                "initial": pt.as_tensor_variable(0.0, dtype=pytensor.config.floatX),
                 "taps": [-1],
             },
         ],
@@ -126,7 +126,7 @@ def test_convert_outer_out_to_in_sit_sot():
     # Sample from the model and create another `Scan` that computes the
     # log-likelihood of the model at the sampled point.
     #
-    Y_obs = at.as_tensor_variable(Y_rv.eval())
+    Y_obs = pt.as_tensor_variable(Y_rv.eval())
     Y_obs.name = "Y_obs"
 
     def output_step_fn(y_t, y_tm1, mu_tm1):
@@ -134,7 +134,7 @@ def test_convert_outer_out_to_in_sit_sot():
         y_tm1.name = "y_tm1"
         mu = mu_tm1 + y_tm1 + 1
         mu.name = "mu_t"
-        logp = logprob(at.random.normal(mu, 1.0), y_t)
+        logp = _logprob_helper(pt.random.normal(mu, 1.0), y_t)
         logp.name = "logp"
         return mu, logp
 
@@ -143,7 +143,7 @@ def test_convert_outer_out_to_in_sit_sot():
         sequences=[{"input": Y_obs, "taps": [0, -1]}],
         outputs_info=[
             {
-                "initial": at.as_tensor_variable(0.0, dtype=pytensor.config.floatX),
+                "initial": pt.as_tensor_variable(0.0, dtype=pytensor.config.floatX),
                 "taps": [-1],
             },
             {},
@@ -203,12 +203,12 @@ def test_convert_outer_out_to_in_mit_sot():
     def input_step_fn(y_tm1, y_tm2, rng):
         y_tm1.name = "y_tm1"
         y_tm2.name = "y_tm2"
-        return at.random.normal(y_tm1 + y_tm2, 1.0, rng=rng, name="Y_t")
+        return pt.random.normal(y_tm1 + y_tm2, 1.0, rng=rng, name="Y_t")
 
     Y_rv, _ = pytensor.scan(
         fn=input_step_fn,
         outputs_info=[
-            {"initial": at.as_tensor_variable(np.r_[-1.0, 0.0]), "taps": [-1, -2]},
+            {"initial": pt.as_tensor_variable(np.r_[-1.0, 0.0]), "taps": [-1, -2]},
         ],
         non_sequences=[rng_tt],
         n_steps=10,
@@ -218,7 +218,7 @@ def test_convert_outer_out_to_in_mit_sot():
     Y_all = Y_rv.owner.inputs[0]
     Y_all.name = "Y_all"
 
-    Y_obs = at.as_tensor_variable(Y_rv.eval())
+    Y_obs = pt.as_tensor_variable(Y_rv.eval())
     Y_obs.name = "Y_obs"
 
     input_scan_args = ScanArgs.from_node(Y_rv.owner.inputs[0].owner)
@@ -233,7 +233,7 @@ def test_convert_outer_out_to_in_mit_sot():
         y_t.name = "y_t"
         y_tm1.name = "y_tm1"
         y_tm2.name = "y_tm2"
-        logp = logprob(at.random.normal(y_tm1 + y_tm2, 1.0), y_t)
+        logp = _logprob_helper(pt.random.normal(y_tm1 + y_tm2, 1.0), y_t)
         logp.name = "logp(y_t)"
         return logp
 
@@ -283,25 +283,25 @@ def test_convert_outer_out_to_in_mit_sot():
     ],
 )
 def test_scan_joint_logprob(require_inner_rewrites):
-    srng = at.random.RandomStream()
+    srng = pt.random.RandomStream()
 
-    N_tt = at.iscalar("N")
+    N_tt = pt.iscalar("N")
     N_val = 10
     N_tt.tag.test_value = N_val
 
-    M_tt = at.iscalar("M")
+    M_tt = pt.iscalar("M")
     M_val = 2
     M_tt.tag.test_value = M_val
 
-    mus_tt = at.matrix("mus_t")
+    mus_tt = pt.matrix("mus_t")
 
     mus_val = np.stack([np.arange(0.0, 10), np.arange(0.0, -10, -1)], axis=-1).astype(
         pytensor.config.floatX
     )
     mus_tt.tag.test_value = mus_val
 
-    sigmas_tt = at.ones((N_tt,))
-    Gamma_rv = srng.dirichlet(at.ones((M_tt, M_tt)), name="Gamma")
+    sigmas_tt = pt.ones((N_tt,))
+    Gamma_rv = srng.dirichlet(pt.ones((M_tt, M_tt)), name="Gamma")
 
     Gamma_vv = Gamma_rv.clone()
     Gamma_vv.name = "Gamma_vv"
@@ -357,9 +357,9 @@ def test_scan_joint_logprob(require_inner_rewrites):
     # Construct the joint log-probability by hand so we can compare it with
     # `y_logp`
     def scan_fn(mus_t, sigma_t, Y_t_val, S_t_val, Gamma_t):
-        S_t = at.random.categorical(Gamma_t[0], name="S_t")
-        Y_t = at.random.normal(mus_t[S_t_val], sigma_t, name="Y_t")
-        Y_t_logp, S_t_logp = logprob(Y_t, Y_t_val), logprob(S_t, S_t_val)
+        S_t = pt.random.categorical(Gamma_t[0], name="S_t")
+        Y_t = pt.random.normal(mus_t[S_t_val], sigma_t, name="Y_t")
+        Y_t_logp, S_t_logp = _logprob_helper(Y_t, Y_t_val), _logprob_helper(S_t, S_t_val)
         Y_t_logp.name = "log(Y_t=y_t)"
         S_t_logp.name = "log(S_t=s_t)"
         return Y_t_logp, S_t_logp
@@ -375,7 +375,7 @@ def test_scan_joint_logprob(require_inner_rewrites):
     Y_rv_logp.name = "logp(Y=y)"
     S_rv_logp.name = "logp(S=s)"
 
-    Gamma_logp = logprob(Gamma_rv, Gamma_vv)
+    Gamma_logp = _logprob_helper(Gamma_rv, Gamma_vv)
 
     y_logp_ref = Y_rv_logp.sum() + S_rv_logp.sum() + Gamma_logp.sum()
 
@@ -392,13 +392,13 @@ def test_scan_joint_logprob(require_inner_rewrites):
 @pytensor.config.change_flags(compute_test_value="raise")
 @pytest.mark.xfail(reason="see #148")
 def test_initial_values():
-    srng = at.random.RandomStream(seed=2320)
+    srng = pt.random.RandomStream(seed=2320)
 
     p_S_0 = np.array([0.9, 0.1])
     S_0_rv = srng.categorical(p_S_0, name="S_0")
     S_0_rv.tag.test_value = 0
 
-    Gamma_at = at.matrix("Gamma")
+    Gamma_at = pt.matrix("Gamma")
     Gamma_at.tag.test_value = np.array([[0, 1], [1, 0]])
 
     s_0_vv = S_0_rv.clone()
@@ -444,8 +444,8 @@ def test_initial_values():
 def test_mode_is_kept(remove_asserts):
     mode = Mode().including("local_remove_all_assert") if remove_asserts else None
     x, _ = pytensor.scan(
-        fn=lambda x: at.random.normal(assert_op(x, x > 0)),
-        outputs_info=[at.ones(())],
+        fn=lambda x: pt.random.normal(assert_op(x, x > 0)),
+        outputs_info=[pt.ones(())],
         n_steps=10,
         mode=mode,
     )
@@ -463,8 +463,8 @@ def test_mode_is_kept(remove_asserts):
 
 def test_scan_non_pure_rv_output():
     grw, _ = pytensor.scan(
-        fn=lambda xtm1: at.random.normal() + xtm1,
-        outputs_info=[at.zeros(())],
+        fn=lambda xtm1: pt.random.normal() + xtm1,
+        outputs_info=[pt.zeros(())],
         n_steps=10,
         name="grw",
     )
@@ -478,3 +478,79 @@ def test_scan_non_pure_rv_output():
         grw_logp.eval({grw_vv: grw_vv_test}),
         stats.norm.logpdf(np.ones(10)),
     )
+
+
+def test_scan_over_seqs():
+    """Test that logprob inference for scans based on sequences (mapping)."""
+    rng = np.random.default_rng(543)
+    n_steps = 10
+
+    xs = pt.random.normal(size=(n_steps,), name="xs")
+    ys, _ = pytensor.scan(
+        fn=lambda x: pt.random.normal(x), sequences=[xs], outputs_info=[None], name="ys"
+    )
+
+    xs_vv = ys.clone()
+    ys_vv = ys.clone()
+    ys_logp = factorized_joint_logprob({xs: xs_vv, ys: ys_vv})[ys_vv]
+
+    assert_no_rvs(ys_logp)
+
+    xs_test = rng.normal(size=(10,))
+    ys_test = rng.normal(size=(10,))
+    np.testing.assert_array_almost_equal(
+        ys_logp.eval({xs_vv: xs_test, ys_vv: ys_test}),
+        stats.norm.logpdf(ys_test, xs_test),
+    )
+
+
+def test_scan_carried_deterministic_state():
+    """Test logp of scans with carried states downstream of measured variables.
+
+    A moving average model with 2 lags is used for testing.
+    """
+    rng = np.random.default_rng(490)
+    steps = 99
+
+    rho = pt.vector("rho", shape=(2,))
+    sigma = pt.scalar("sigma")
+
+    def ma2_step(eps_tm2, eps_tm1, rho, sigma):
+        mu = eps_tm1 * rho[0] + eps_tm2 * rho[1]
+        y = pt.random.normal(mu, sigma)
+        eps = y - mu
+        update = {y.owner.inputs[0]: y.owner.outputs[0]}
+        return (eps, y), update
+
+    [_, ma2], ma2_updates = pytensor.scan(
+        fn=ma2_step,
+        outputs_info=[{"initial": pt.arange(2, dtype="float64"), "taps": range(-2, 0)}, None],
+        non_sequences=[rho, sigma],
+        n_steps=steps,
+        strict=True,
+        name="ma2",
+    )
+
+    def ref_logp(values, rho, sigma):
+        epsilon_tm2 = 0
+        epsilon_tm1 = 1
+        step_logps = np.zeros_like(values)
+        for t, value in enumerate(values):
+            mu = epsilon_tm1 * rho[0] + epsilon_tm2 * rho[1]
+            step_logps[t] = stats.norm.logpdf(value, mu, sigma)
+            epsilon_tm2 = epsilon_tm1
+            epsilon_tm1 = value - mu
+        return step_logps
+
+    ma2_vv = ma2.clone()
+    logp_expr = logp(ma2, ma2_vv)
+    assert_no_rvs(logp_expr)
+
+    ma2_test = rng.normal(size=(steps,))
+    rho_test = np.array([0.3, 0.7])
+    sigma_test = 0.9
+
+    np.testing.assert_array_almost_equal(
+        logp_expr.eval({ma2_vv: ma2_test, rho: rho_test, sigma: sigma_test}),
+        ref_logp(ma2_test, rho_test, sigma_test),
+    )
