@@ -36,7 +36,7 @@
 
 import numpy as np
 import pytensor
-import pytensor.tensor as at
+import pytensor.tensor as pt
 import pytest
 import scipy as sp
 import scipy.special
@@ -49,7 +49,7 @@ from pytensor.scan import scan
 
 from pymc.distributions.transforms import _default_transform, log, logodds
 from pymc.logprob.abstract import MeasurableVariable, _get_measurable_outputs, _logprob
-from pymc.logprob.joint_logprob import factorized_joint_logprob
+from pymc.logprob.basic import factorized_joint_logprob
 from pymc.logprob.transforms import (
     ChainedTransform,
     ExpTransform,
@@ -94,15 +94,15 @@ class DirichletScipyDist:
 @pytest.mark.parametrize(
     "at_dist, dist_params, sp_dist, size",
     [
-        (at.random.uniform, (0, 1), sp.stats.uniform, ()),
+        (pt.random.uniform, (0, 1), sp.stats.uniform, ()),
         (
-            at.random.pareto,
+            pt.random.pareto,
             (1.5, 10.5),
             lambda b, scale: sp.stats.pareto(b, scale=scale),
             (),
         ),
         (
-            at.random.triangular,
+            pt.random.triangular,
             (1.5, 3.0, 10.5),
             lambda lower, mode, upper: sp.stats.triang(
                 (mode - lower) / (upper - lower), loc=lower, scale=upper - lower
@@ -110,13 +110,13 @@ class DirichletScipyDist:
             (),
         ),
         (
-            at.random.halfnormal,
+            pt.random.halfnormal,
             (0, 1),
             sp.stats.halfnorm,
             (),
         ),
         pytest.param(
-            at.random.wald,
+            pt.random.wald,
             (1.5, 10.5),
             lambda mean, scale: sp.stats.invgauss(mean / scale, scale=scale),
             (),
@@ -126,49 +126,49 @@ class DirichletScipyDist:
             ),
         ),
         (
-            at.random.exponential,
+            pt.random.exponential,
             (1.5,),
             lambda mu: sp.stats.expon(scale=mu),
             (),
         ),
         pytest.param(
-            at.random.lognormal,
+            pt.random.lognormal,
             (-1.5, 10.5),
             lambda mu, sigma: sp.stats.lognorm(s=sigma, loc=0, scale=np.exp(mu)),
             (),
         ),
         (
-            at.random.lognormal,
+            pt.random.lognormal,
             (-1.5, 1.5),
             lambda mu, sigma: sp.stats.lognorm(s=sigma, scale=np.exp(mu)),
             (),
         ),
         (
-            at.random.halfcauchy,
+            pt.random.halfcauchy,
             (1.5, 10.5),
             lambda alpha, beta: sp.stats.halfcauchy(loc=alpha, scale=beta),
             (),
         ),
         (
-            at.random.gamma,
+            pt.random.gamma,
             (1.5, 10.5),
             lambda alpha, inv_beta: sp.stats.gamma(alpha, scale=1.0 / inv_beta),
             (),
         ),
         (
-            at.random.invgamma,
+            pt.random.invgamma,
             (1.5, 10.5),
             lambda alpha, beta: sp.stats.invgamma(alpha, scale=beta),
             (),
         ),
         (
-            at.random.chisquare,
+            pt.random.chisquare,
             (1.5,),
             lambda df: sp.stats.chi2(df),
             (),
         ),
         pytest.param(
-            at.random.weibull,
+            pt.random.weibull,
             (1.5,),
             lambda c: sp.stats.weibull_min(c),
             (),
@@ -178,31 +178,31 @@ class DirichletScipyDist:
             ),
         ),
         (
-            at.random.beta,
+            pt.random.beta,
             (1.5, 1.5),
             lambda alpha, beta: sp.stats.beta(alpha, beta),
             (),
         ),
         (
-            at.random.vonmises,
+            pt.random.vonmises,
             (1.5, 10.5),
             lambda mu, kappa: sp.stats.vonmises(kappa, loc=mu),
             (),
         ),
         (
-            at.random.dirichlet,
+            pt.random.dirichlet,
             (np.array([0.7, 0.3]),),
             lambda alpha: sp.stats.dirichlet(alpha),
             (),
         ),
         (
-            at.random.dirichlet,
+            pt.random.dirichlet,
             (np.array([[0.7, 0.3], [0.9, 0.1]]),),
             lambda alpha: DirichletScipyDist(alpha),
             (),
         ),
         pytest.param(
-            at.random.dirichlet,
+            pt.random.dirichlet,
             (np.array([0.3, 0.7]),),
             lambda alpha: DirichletScipyDist(alpha),
             (3, 2),
@@ -213,7 +213,7 @@ def test_transformed_logprob(at_dist, dist_params, sp_dist, size):
     """
     This test takes a `RandomVariable` type, plus parameters, and uses it to
     construct a variable ``a`` that's used in the graph ``b =
-    at.random.normal(a, 1.0)``.  The transformed log-probability is then
+    pt.random.normal(a, 1.0)``.  The transformed log-probability is then
     computed for ``b``.  We then test that the log-probability of ``a`` is
     properly transformed, as well as any instances of ``a`` that are used
     elsewhere in the graph (i.e. in ``b``), by comparing the graph for the
@@ -225,10 +225,10 @@ def test_transformed_logprob(at_dist, dist_params, sp_dist, size):
 
     a = at_dist(*dist_params, size=size)
     a.name = "a"
-    a_value_var = at.tensor(dtype=a.dtype, shape=(None,) * a.ndim)
+    a_value_var = pt.tensor(dtype=a.dtype, shape=(None,) * a.ndim)
     a_value_var.name = "a_value"
 
-    b = at.random.normal(a, 1.0)
+    b = pt.random.normal(a, 1.0)
     b.name = "b"
     b_value_var = b.clone()
     b_value_var.name = "b_value"
@@ -303,7 +303,7 @@ def test_transformed_logprob(at_dist, dist_params, sp_dist, size):
 
 @pytest.mark.parametrize("use_jacobian", [True, False])
 def test_simple_transformed_logprob_nojac(use_jacobian):
-    X_rv = at.random.halfnormal(0, 3, name="X")
+    X_rv = pt.random.halfnormal(0, 3, name="X")
     x_vv = X_rv.clone()
     x_vv.name = "x"
 
@@ -329,14 +329,14 @@ def test_fallback_log_jac_det(ndim):
         name = "square"
 
         def forward(self, value, *inputs):
-            return at.power(value, 2)
+            return pt.power(value, 2)
 
         def backward(self, value, *inputs):
-            return at.sqrt(value)
+            return pt.sqrt(value)
 
     square_tr = SquareTransform()
 
-    value = at.TensorType("float64", (None,) * ndim)("value")
+    value = pt.TensorType("float64", (None,) * ndim)("value")
     value_tr = square_tr.forward(value)
     log_jac_det = square_tr.log_jac_det(value_tr)
 
@@ -351,9 +351,9 @@ def test_hierarchical_uniform_transform():
     the value var `x`
     """
 
-    lower_rv = at.random.uniform(0, 1, name="lower")
-    upper_rv = at.random.uniform(9, 10, name="upper")
-    x_rv = at.random.uniform(lower_rv, upper_rv, name="x")
+    lower_rv = pt.random.uniform(0, 1, name="lower")
+    upper_rv = pt.random.uniform(9, 10, name="upper")
+    x_rv = pt.random.uniform(lower_rv, upper_rv, name="x")
 
     lower = lower_rv.clone()
     upper = upper_rv.clone()
@@ -376,9 +376,9 @@ def test_hierarchical_uniform_transform():
 
 
 def test_nondefault_transforms():
-    loc_rv = at.random.uniform(-10, 10, name="loc")
-    scale_rv = at.random.uniform(-1, 1, name="scale")
-    x_rv = at.random.normal(loc_rv, scale_rv, name="x")
+    loc_rv = pt.random.uniform(-10, 10, name="loc")
+    scale_rv = pt.random.uniform(-1, 1, name="scale")
+    x_rv = pt.random.normal(loc_rv, scale_rv, name="x")
 
     loc = loc_rv.clone()
     scale = scale_rv.clone()
@@ -423,8 +423,8 @@ def test_default_transform_multiout():
 
     # This SVD value is necessarily `1`, but it's generated by an `Op` with
     # multiple outputs and no default output.
-    sd = at.linalg.svd(at.eye(1))[1][0]
-    x_rv = at.random.normal(0, sd, name="x")
+    sd = pt.linalg.svd(pt.eye(1))[1][0]
+    x_rv = pt.random.normal(0, sd, name="x")
     x = x_rv.clone()
 
     transform_rewrite = TransformValuesRewrite({x: None})
@@ -443,7 +443,7 @@ def test_default_transform_multiout():
 @pytest.fixture(scope="module")
 def multiout_measurable_op():
     # Create a dummy Op that just returns the two inputs
-    mu1, mu2 = at.scalars("mu1", "mu2")
+    mu1, mu2 = pt.scalars("mu1", "mu2")
 
     class TestOpFromGraph(OpFromGraph):
         def do_constant_folding(self, fgraph, node):
@@ -501,7 +501,7 @@ def test_nondefault_transform_multiout(transform_x, transform_y, multiout_measur
 
 
 def test_TransformValuesMapping():
-    x = at.vector()
+    x = pt.vector()
     fg = FunctionGraph(outputs=[x])
 
     tvm = TransformValuesMapping({})
@@ -518,7 +518,7 @@ def test_original_values_output_dict():
     Test that the original unconstrained value variable appears an the key of
     the logprob factor
     """
-    p_rv = at.random.beta(1, 1, name="p")
+    p_rv = pt.random.beta(1, 1, name="p")
     p_vv = p_rv.clone()
 
     tr = TransformValuesRewrite({p_vv: logodds})
@@ -533,13 +533,13 @@ def test_mixture_transform():
     This test is specific to `MixtureRV`, which is derived from an `OpFromGraph`.
     """
 
-    I_rv = at.random.bernoulli(0.5, name="I")
-    Y_1_rv = at.random.beta(100, 1, name="Y_1")
-    Y_2_rv = at.random.beta(1, 100, name="Y_2")
+    I_rv = pt.random.bernoulli(0.5, name="I")
+    Y_1_rv = pt.random.beta(100, 1, name="Y_1")
+    Y_2_rv = pt.random.beta(1, 100, name="Y_2")
 
     # A `MixtureRV`, which is an `OpFromGraph` subclass, will replace this
-    # `at.stack` in the graph
-    Y_rv = at.stack([Y_1_rv, Y_2_rv])[I_rv]
+    # `pt.stack` in the graph
+    Y_rv = pt.stack([Y_1_rv, Y_2_rv])[I_rv]
     Y_rv.name = "Y"
 
     i_vv = I_rv.clone()
@@ -566,7 +566,7 @@ def test_mixture_transform():
     # The untransformed graph should be the same as the transformed graph after
     # replacing the `Y_rv` value variable with a transformed version of itself
     logp_nt_fg = FunctionGraph(outputs=[logp_no_trans], clone=False)
-    y_trans = transformed_variable(at.exp(y_vv), y_vv)
+    y_trans = transformed_variable(pt.exp(y_vv), y_vv)
     y_trans.name = "y_log"
     logp_nt_fg.replace(y_vv, y_trans)
     logp_nt = logp_nt_fg.outputs[0]
@@ -575,7 +575,7 @@ def test_mixture_transform():
 
 
 def test_invalid_interval_transform():
-    x_rv = at.random.normal(0, 1)
+    x_rv = pt.random.normal(0, 1)
     x_vv = x_rv.clone()
 
     msg = "Both edges of IntervalTransform cannot be None"
@@ -599,17 +599,17 @@ def test_chained_transform():
     ch = ChainedTransform(
         transform_list=[
             ScaleTransform(
-                transform_args_fn=lambda *inputs: at.constant(scale),
+                transform_args_fn=lambda *inputs: pt.constant(scale),
             ),
             ExpTransform(),
             LocTransform(
-                transform_args_fn=lambda *inputs: at.constant(loc),
+                transform_args_fn=lambda *inputs: pt.constant(loc),
             ),
         ],
-        base_op=at.random.multivariate_normal,
+        base_op=pt.random.multivariate_normal,
     )
 
-    x = at.random.multivariate_normal(np.zeros(3), np.eye(3))
+    x = pt.random.multivariate_normal(np.zeros(3), np.eye(3))
     x_val = x.eval()
 
     x_val_forward = ch.forward(x_val, *x.owner.inputs).eval()
@@ -626,14 +626,14 @@ def test_chained_transform():
 
     log_jac_det = ch.log_jac_det(x_val_forward, *x.owner.inputs, scale, loc)
     assert np.isclose(
-        log_jac_det.eval(),
-        -np.log(scale) - np.sum(np.log(x_val_forward - loc)),
+        pt.sum(log_jac_det).eval(),
+        np.sum(-np.log(scale) - np.log(x_val_forward - loc)),
     )
 
 
 def test_exp_transform_rv():
-    base_rv = at.random.normal(0, 1, size=3, name="base_rv")
-    y_rv = at.exp(base_rv)
+    base_rv = pt.random.normal(0, 1, size=3, name="base_rv")
+    y_rv = pt.exp(base_rv)
     y_rv.name = "y"
 
     y_vv = y_rv.clone()
@@ -648,8 +648,8 @@ def test_exp_transform_rv():
 
 
 def test_log_transform_rv():
-    base_rv = at.random.lognormal(0, 1, size=2, name="base_rv")
-    y_rv = at.log(base_rv)
+    base_rv = pt.random.lognormal(0, 1, size=2, name="base_rv")
+    y_rv = pt.log(base_rv)
     y_rv.name = "y"
 
     y_vv = y_rv.clone()
@@ -666,17 +666,17 @@ def test_log_transform_rv():
 @pytest.mark.parametrize(
     "rv_size, loc_type, addition",
     [
-        (None, at.scalar, True),
-        (2, at.vector, False),
-        ((2, 1), at.col, True),
+        (None, pt.scalar, True),
+        (2, pt.vector, False),
+        ((2, 1), pt.col, True),
     ],
 )
 def test_loc_transform_rv(rv_size, loc_type, addition):
     loc = loc_type("loc")
     if addition:
-        y_rv = loc + at.random.normal(0, 1, size=rv_size, name="base_rv")
+        y_rv = loc + pt.random.normal(0, 1, size=rv_size, name="base_rv")
     else:
-        y_rv = at.random.normal(0, 1, size=rv_size, name="base_rv") - at.neg(loc)
+        y_rv = pt.random.normal(0, 1, size=rv_size, name="base_rv") - pt.neg(loc)
     y_rv.name = "y"
     y_vv = y_rv.clone()
 
@@ -696,17 +696,17 @@ def test_loc_transform_rv(rv_size, loc_type, addition):
 @pytest.mark.parametrize(
     "rv_size, scale_type, product",
     [
-        (None, at.scalar, True),
-        (1, at.TensorType("floatX", (True,)), True),
-        ((2, 3), at.matrix, False),
+        (None, pt.scalar, True),
+        (1, pt.TensorType("floatX", (True,)), True),
+        ((2, 3), pt.matrix, False),
     ],
 )
 def test_scale_transform_rv(rv_size, scale_type, product):
     scale = scale_type("scale")
     if product:
-        y_rv = at.random.normal(0, 1, size=rv_size, name="base_rv") * scale
+        y_rv = pt.random.normal(0, 1, size=rv_size, name="base_rv") * scale
     else:
-        y_rv = at.random.normal(0, 1, size=rv_size, name="base_rv") / at.reciprocal(scale)
+        y_rv = pt.random.normal(0, 1, size=rv_size, name="base_rv") / pt.reciprocal(scale)
     y_rv.name = "y"
     y_vv = y_rv.clone()
 
@@ -724,7 +724,7 @@ def test_scale_transform_rv(rv_size, scale_type, product):
 
 
 def test_transformed_rv_and_value():
-    y_rv = at.random.halfnormal(-1, 1, name="base_rv") + 1
+    y_rv = pt.random.halfnormal(-1, 1, name="base_rv") + 1
     y_rv.name = "y"
     y_vv = y_rv.clone()
 
@@ -743,8 +743,8 @@ def test_transformed_rv_and_value():
 
 
 def test_loc_transform_multiple_rvs_fails1():
-    x_rv1 = at.random.normal(name="x_rv1")
-    x_rv2 = at.random.normal(name="x_rv2")
+    x_rv1 = pt.random.normal(name="x_rv1")
+    x_rv2 = pt.random.normal(name="x_rv2")
     y_rv = x_rv1 + x_rv2
 
     y = y_rv.clone()
@@ -754,8 +754,8 @@ def test_loc_transform_multiple_rvs_fails1():
 
 
 def test_nested_loc_transform_multiple_rvs_fails2():
-    x_rv1 = at.random.normal(name="x_rv1")
-    x_rv2 = at.cos(at.random.normal(name="x_rv2"))
+    x_rv1 = pt.random.normal(name="x_rv1")
+    x_rv2 = pt.cos(pt.random.normal(name="x_rv2"))
     y_rv = x_rv1 + x_rv2
 
     y = y_rv.clone()
@@ -765,21 +765,21 @@ def test_nested_loc_transform_multiple_rvs_fails2():
 
 
 def test_discrete_rv_unary_transform_fails():
-    y_rv = at.exp(at.random.poisson(1))
+    y_rv = pt.exp(pt.random.poisson(1))
     with pytest.raises(RuntimeError, match="could not be derived"):
         joint_logprob({y_rv: y_rv.clone()})
 
 
 def test_discrete_rv_multinary_transform_fails():
-    y_rv = 5 + at.random.poisson(1)
+    y_rv = 5 + pt.random.poisson(1)
     with pytest.raises(RuntimeError, match="could not be derived"):
         joint_logprob({y_rv: y_rv.clone()})
 
 
 @pytest.mark.xfail(reason="Check not implemented yet")
 def test_invalid_broadcasted_transform_rv_fails():
-    loc = at.vector("loc")
-    y_rv = loc + at.random.normal(0, 1, size=1, name="base_rv")
+    loc = pt.vector("loc")
+    y_rv = loc + pt.random.normal(0, 1, size=1, name="base_rv")
     y_rv.name = "y"
     y_vv = y_rv.clone()
 
@@ -792,7 +792,7 @@ def test_invalid_broadcasted_transform_rv_fails():
 def test_reciprocal_rv_transform(numerator):
     shape = 3
     scale = 5
-    x_rv = numerator / at.random.gamma(shape, scale, size=(2,))
+    x_rv = numerator / pt.random.gamma(shape, scale, size=(2,))
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
@@ -807,7 +807,7 @@ def test_reciprocal_rv_transform(numerator):
 
 def test_sqr_transform():
     # The square of a unit normal is a chi-square with 1 df
-    x_rv = at.random.normal(0, 1, size=(4,)) ** 2
+    x_rv = pt.random.normal(0, 1, size=(4,)) ** 2
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
@@ -822,7 +822,7 @@ def test_sqr_transform():
 
 def test_sqrt_transform():
     # The sqrt of a chisquare with n df is a chi distribution with n df
-    x_rv = at.sqrt(at.random.chisquare(df=3, size=(4,)))
+    x_rv = pt.sqrt(pt.random.chisquare(df=3, size=(4,)))
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
@@ -838,7 +838,7 @@ def test_sqrt_transform():
 @pytest.mark.parametrize("power", (-3, -1, 1, 5, 7))
 def test_negative_value_odd_power_transform(power):
     # check that negative values and odd powers evaluate to a finite logp
-    x_rv = at.random.normal() ** power
+    x_rv = pt.random.normal() ** power
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
@@ -851,7 +851,7 @@ def test_negative_value_odd_power_transform(power):
 @pytest.mark.parametrize("power", (-2, 2, 4, 6, 8))
 def test_negative_value_even_power_transform(power):
     # check that negative values and odd powers evaluate to -inf logp
-    x_rv = at.random.normal() ** power
+    x_rv = pt.random.normal() ** power
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
@@ -864,7 +864,7 @@ def test_negative_value_even_power_transform(power):
 @pytest.mark.parametrize("power", (-1 / 3, -1 / 2, 1 / 2, 1 / 3))
 def test_negative_value_frac_power_transform(power):
     # check that negative values and fractional powers evaluate to -inf logp
-    x_rv = at.random.normal() ** power
+    x_rv = pt.random.normal() ** power
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
@@ -876,8 +876,8 @@ def test_negative_value_frac_power_transform(power):
 
 @pytest.mark.parametrize("test_val", (2.5, -2.5))
 def test_absolute_transform(test_val):
-    x_rv = at.abs(at.random.normal())
-    y_rv = at.random.halfnormal()
+    x_rv = pt.abs(pt.random.normal())
+    y_rv = pt.random.halfnormal()
 
     x_vv = x_rv.clone()
     y_vv = y_rv.clone()
@@ -888,7 +888,7 @@ def test_absolute_transform(test_val):
 
 
 def test_negated_rv_transform():
-    x_rv = -at.random.halfnormal()
+    x_rv = -pt.random.halfnormal()
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
@@ -899,7 +899,7 @@ def test_negated_rv_transform():
 
 def test_subtracted_rv_transform():
     # Choose base RV that is asymmetric around zero
-    x_rv = 5.0 - at.random.normal(1.0)
+    x_rv = 5.0 - pt.random.normal(1.0)
     x_rv.name = "x"
 
     x_vv = x_rv.clone()
@@ -911,11 +911,11 @@ def test_subtracted_rv_transform():
 def test_scan_transform():
     """Test that Scan valued variables can be transformed"""
 
-    init = at.random.beta(1, 1, name="init")
+    init = pt.random.beta(1, 1, name="init")
     init_vv = init.clone()
 
     def scan_step(prev_innov):
-        next_innov = at.random.beta(prev_innov * 10, (1 - prev_innov) * 10)
+        next_innov = pt.random.beta(prev_innov * 10, (1 - prev_innov) * 10)
         update = {next_innov.owner.inputs[0]: next_innov.owner.outputs[0]}
         return next_innov, update
 
@@ -942,10 +942,10 @@ def test_scan_transform():
     innov = []
     prev_innov = init
     for i in range(4):
-        next_innov = at.random.beta(prev_innov * 10, (1 - prev_innov) * 10, name=f"innov[i]")
+        next_innov = pt.random.beta(prev_innov * 10, (1 - prev_innov) * 10, name=f"innov[i]")
         innov.append(next_innov)
         prev_innov = next_innov
-    innov = at.stack(innov)
+    innov = pt.stack(innov)
     innov.name = "innov"
 
     tr = TransformValuesRewrite(
@@ -964,3 +964,28 @@ def test_scan_transform():
         "innov": np.full((4,), -0.5),
     }
     np.testing.assert_allclose(logp_fn(**test_point), ref_logp_fn(**test_point))
+
+
+@pytest.mark.parametrize("shift", [1.5, np.array([-0.5, 1, 0.3])])
+@pytest.mark.parametrize("scale", [2.0, np.array([1.5, 3.3, 1.0])])
+def test_multivariate_transform(shift, scale):
+    mu = np.array([0, 0.9, -2.1])
+    cov = np.array([[1, 0, 0.9], [0, 1, 0], [0.9, 0, 1]])
+    x_rv_raw = pt.random.multivariate_normal(mu, cov=cov)
+    x_rv = shift + x_rv_raw * scale
+    x_rv.name = "x"
+
+    x_vv = x_rv.clone()
+    logp = factorized_joint_logprob({x_rv: x_vv})[x_vv]
+    assert_no_rvs(logp)
+
+    x_vv_test = np.array([5.0, 4.9, -6.3])
+    scale_mat = scale * np.eye(x_vv_test.shape[0])
+    np.testing.assert_almost_equal(
+        logp.eval({x_vv: x_vv_test}),
+        sp.stats.multivariate_normal.logpdf(
+            x_vv_test,
+            shift + mu * scale,
+            scale_mat @ cov @ scale_mat.T,
+        ),
+    )
